==> aliyun_python_sdk_dataworks_public-3.4.12-py2.py3-none-any.whl: aliyunsdkdataworks_public/request/v20200518/UpdateWorkbenchEventResultRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class UpdateWorkbenchEventResultRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'UpdateWorkbenchEventResult')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_CheckResultTip(self): # String
		return self.get_query_params().get('CheckResultTip')

	def set_CheckResultTip(self, CheckResultTip):  # String
		self.add_query_param('CheckResultTip', CheckResultTip)
	def get_CheckResult(self): # String
		return self.get_query_params().get('CheckResult')

	def set_CheckResult(self, CheckResult):  # String
		self.add_query_param('CheckResult', CheckResult)
	def get_MessageId(self): # String
		return self.get_query_params().get('MessageId')

	def set_MessageId(self, MessageId):  # String
		self.add_query_param('MessageId', MessageId)
	def get_ExtensionCode(self): # String
		return self.get_query_params().get('ExtensionCode')

	def set_ExtensionCode(self, ExtensionCode):  # String
		self.add_query_param('ExtensionCode', ExtensionCode)

==> aliyun_python_sdk_dataworks_public-3.4.13-py2.py3-none-any.whl: aliyunsdkdataworks_public/request/v20200518/UpdateWorkbenchEventResultRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class UpdateWorkbenchEventResultRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'UpdateWorkbenchEventResult')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_CheckResultTip(self):
		return self.get_query_params().get('CheckResultTip')

	def set_CheckResultTip(self,CheckResultTip):
		self.add_query_param('CheckResultTip',CheckResultTip)

	def get_CheckResult(self):
		return self.get_query_params().get('CheckResult')

	def set_CheckResult(self,CheckResult):
		self.add_query_param('CheckResult',CheckResult)

	def get_MessageId(self):
		return self.get_query_params().get('MessageId')

	def set_MessageId(self,MessageId):
		self.add_query_param('MessageId',MessageId)

	def get_ExtensionCode(self):
		return self.get_query_params().get('ExtensionCode')

	def set_ExtensionCode(self,ExtensionCode):
		self.add_query_param('ExtensionCode',ExtensionCode)
